/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.portlet.orchestra;

import java.util.HashMap;

import org.exoplatform.webui.core.UIComponent;
import org.exoplatform.webui.event.Event;
import org.exoplatform.webui.event.EventListener;
import org.ow2.orchestra.console.webui.novaview.UINovaView;
import org.ow2.orchestra.console.webui.novaview.UINovaViewContainer;
import org.ow2.orchestra.console.webui.novaview.UINovaViewFactory;
import org.ow2.orchestra.console.webui.novaview.UINovaViewManagement;

/**
 * OrchestraManagementListener is a class that regroup all the listeners
 * associated to the Orchestra Management portlet.
 * 
 * @author Le Jeune Goulven <goulven.le-jeune@bull.net> 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
 */
public class OrchestraManagementListener {

  /**
   * This subclass is the listener of the view process event. It display an
   * overview of the selected process and the associated instances list.
   * 
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   */
  public static class ViewProcessActionListener extends EventListener<UINovaViewFactory> {

    /**
     * The execute method of the listener
     * 
     * @throws Exception
     */
    public void execute(Event<UINovaViewFactory> event) throws Exception {
      // Get the process ID
      String processName = event.getRequestContext().getRequestParameter(UIComponent.OBJECTID);
      String pduuid = event.getRequestContext().getRequestParameter("processDefinitionUUID");

      // Get the ViewManagement
      UINovaViewFactory factory = event.getSource();
      UINovaViewManagement viewMgt = (UINovaViewManagement) factory.getParent();
      // add a view in a tab
      if (!viewMgt.hasView(processName)) {
        // First create the view
        UINovaViewContainer view = viewMgt.addViewContainerAsView(UINovaViewContainer.class, 
                                                                  "CompleteNavigation", 
                                                                  processName, 
                                                                  null, 
                                                                  "Tabs");
        UIProcess process = view.addChild(UIProcess.class, null, "o-" + processName);
        process.setDisplayName("Overview");
        UIInstance instances = view.addChild(UIInstance.class, null, "i-" + processName).setRendered(false);
        instances.setDisplayName("Instances");
        process.init();
        instances.init();
        HashMap<String, String> params = new HashMap<String, String>();
        params.put("name", processName);
        params.put("processDefinitionUUID", pduuid);
        process.setParams(params);
        process.setDetail();
        //instances.setParams(params);
      }
      viewMgt.showView(processName);
    }
  }

  /**
   * This subclass is the listener of the view instance event. It display an
   * overview of the selected instance and the associated variables and
   * activities lists.
   * 
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   */
  public static class ViewInstanceActionListener extends EventListener<UINovaViewFactory> {

    /**
     * The execute method of the listener
     * 
     * @throws Exception
     */
    public void execute(Event<UINovaViewFactory> event) throws Exception {
      // Get the instance ID
      String instanceId = event.getRequestContext().getRequestParameter(UIComponent.OBJECTID);

      // Get the ViewManagement
      UINovaViewFactory factory = event.getSource();
      UINovaViewManagement viewMgt = (UINovaViewManagement) factory.getParent();
      // add a view in a tab
      if (!viewMgt.hasView(instanceId)) {
        // First create the view
        UINovaView view = viewMgt.addView(UINovaView.class, "CompleteNavigation", instanceId, null, "Tabs");
        // add instance
        UIInstance instance = view.addChild(UIInstance.class, null, "o-" + instanceId);
        instance.setDisplayName("Overview");
        instance.init();

        HashMap<String, String> params = new HashMap<String, String>();
        params.put("id", instanceId);
        instance.setParams(params);
        instance.setDetail();
      }
      viewMgt.showView(instanceId);
    }
  }
}
