/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.portlet.orchestra;

import org.exoplatform.portal.webui.portal.UIPortalComponentActionListener;
import org.exoplatform.webui.config.annotation.ComponentConfig;
import org.exoplatform.webui.config.annotation.ComponentConfigs;
import org.exoplatform.webui.config.annotation.EventConfig;
import org.exoplatform.webui.core.lifecycle.UIApplicationLifecycle;
import org.ow2.orchestra.console.portlet.orchestra.OrchestraManagementListener.ViewInstanceActionListener;
import org.ow2.orchestra.console.portlet.orchestra.OrchestraManagementListener.ViewProcessActionListener;
import org.ow2.orchestra.console.webui.commons.UINovaPortlet;
import org.ow2.orchestra.console.webui.novaview.UINovaViewContainer;
import org.ow2.orchestra.console.webui.novaview.UINovaViewManagement;
import org.ow2.orchestra.console.webui.novaview.UINovaViewTabulation;

/**
 * OrchestraManagementPortlet is the portlet that allow to access to those
 * funcionnalities : - Consult a list of deployed orchestra processes - Consult
 * a list of process orchestra instances - Deploy orchestra process - Undeploy
 * orchestra process - Start orchestra process - Delete instance
 * 
 * @author Le Jeune Goulven <goulven.le-jeune@bull.net> 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 * @author Rodrigue Le Gall <rodrigue.le-gall@bull.net>
 */

@ComponentConfigs({
    @ComponentConfig(id = "Factory", events = {
        @EventConfig(listeners = ViewProcessActionListener.class), @EventConfig(listeners = ViewInstanceActionListener.class)
    }),
    @ComponentConfig(id = "Tabulation", template = "system:/groovy/novabpm/commons/webui/Tabulation.gtmpl", events = {
        @EventConfig(listeners = UINovaViewManagement.ViewChildActionListener.class), 
        @EventConfig(listeners = UINovaViewManagement.CloseViewActionListener.class)
    }),
    @ComponentConfig(id = "SimpleNavigation", 
                     template = "system:/groovy/novabpm/commons/webui/SimpleNavigation.gtmpl", 
                     events = @EventConfig(listeners = UINovaViewManagement.ViewChildActionListener.class)),
    @ComponentConfig(id = "SimpleNavigationHeader", 
                     template = "system:/groovy/novabpm/commons/webui/SimpleNavigationHeader.gtmpl", 
                     events = @EventConfig(listeners = UINovaViewManagement.ViewChildActionListener.class)),
    @ComponentConfig(id = "CompleteNavigation", 
                     template = "system:/groovy/novabpm/commons/webui/CompleteNavigation.gtmpl", 
                     events = @EventConfig(listeners = UIPortalComponentActionListener.ViewChildActionListener.class)),
    @ComponentConfig(lifecycle = UIApplicationLifecycle.class)
})
public class OrchestraManagementPortlet extends UINovaPortlet {

  /**
   * @throws Exception
   */
  public OrchestraManagementPortlet() throws Exception {
    super();
    UINovaViewManagement viewMgt = addChild(UINovaViewManagement.class, null, "ViewManagement");
    viewMgt.setConfigFactory("Factory");
    viewMgt.addViewContainer(UINovaViewContainer.class, "SimpleNavigationHeader", "Navigation");
    viewMgt.addViewContainer(UINovaViewTabulation.class, "Tabulation", "Tabs");
    UIProcess uiProcess = (UIProcess) viewMgt.addView(UIProcess.class, null, "Processes", null, "Navigation");

    uiProcess.addChild(UIUploadProcess.class, null, "UIOrchestraUploadProcess");

    viewMgt.addView(UIInstance.class, null, "Instances", null, "Navigation");
    viewMgt.showView("Processes");
  }
}
