/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.portlet.orchestra;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Set;

import org.exoplatform.webui.config.annotation.ComponentConfig;
import org.exoplatform.webui.config.annotation.EventConfig;
import org.exoplatform.webui.core.UIComponent;
import org.exoplatform.webui.event.Event;
import org.exoplatform.webui.event.EventListener;
import org.ow2.orchestra.console.service.orchestra.DeploymentException;
import org.ow2.orchestra.console.service.orchestra.OrchestraService;
import org.ow2.orchestra.console.webui.commons.NovaData;
import org.ow2.orchestra.console.webui.commons.NovaLink;
import org.ow2.orchestra.console.webui.commons.UINovaGrid;
import org.ow2.orchestra.console.webui.novaview.UINovaView;
import org.ow2.orchestra.console.webui.novaview.UINovaViewManagement;
import org.ow2.orchestra.facade.runtime.ProcessInstance;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;

/**
 * UIInstance is the view component of an instance, it allow to get the
 * instances list from the orchestra business service, consult and also to
 * delete instances.
 * 
 * @author Le Jeune Goulven <goulven.le-jeune@bull.net> 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
 */

@ComponentConfig(
    template = "system:/groovy/novabpm/commons/webui/UINovaView.gtmpl", 
    events = @EventConfig(listeners = UIInstance.DeleteInstanceActionListener.class))
public class UIInstance extends UINovaView {

  /**
   * @throws Exception
   */
  public UIInstance() throws Exception {
    super();
  }

  /**
   * The init method set the configurations of the grid : the different headers
   * and the possible actions.
   * 
   */
  public void init() {
    UINovaGrid grid = this.getGrid();
    String[] header = {"id", 
        "process", 
        "state"
    };
    // String[] ACTION = {"DeleteInstance"};
    grid.setHeader(header);
    grid.setShowAction(false);
    // grid.setVisibleAction(ACTION);

    HashMap<String, NovaLink> links = new HashMap<String, NovaLink>();
    // links.put("id", new NovaLink("id",this.getFactory(),"ViewInstance"));
    String[] params = {"processDefinitionUUID"};
    links.put("process", new NovaLink("process", this.getFactory(), "ViewProcess", params));
    grid.setLink(links);
  }

  /**
   * This method allow to update the grid data. It get the instances list from
   * orchestra service and update the current grid.
   * 
   * @throws DeploymentException 
   */
  public void updateData() throws DeploymentException {
    OrchestraService os = getApplicationComponent(OrchestraService.class);

    Set<ProcessInstance> instances = new HashSet<ProcessInstance>();
    if (!this.isDetail()) {
      if (this.hasParam("name")) {
        instances.addAll(os.getInstances(new ProcessDefinitionUUID(this.getParam("processDefinitionUUID"))));
      } else {
        instances = os.getInstances();
      }
    }

    // create the NovaData array
    ArrayList<NovaData> data = new ArrayList<NovaData>();
    for (ProcessInstance i : instances) {
      String processName = os.getProcess(i.getProcessDefinitionUUID().toString()).getName();
      NovaData d = new NovaData(i);
      d.set("id", i.getProcessInstanceUUID().toString());
      d.set("processDefinitionUUID", i.getProcessDefinitionUUID().toString());
      d.set("process", processName);
      d.set("state", i.getState());
      data.add(d);
    }

    UINovaGrid grid = this.getGrid();
    grid.setData(data);
  }

  /**
   * This subclass is the listener of the delete instance event. It get the
   * selected instance and use the orchestra service to delete it. It also close
   * all the related views and refresh the instances list.
   * 
   */
  public static class DeleteInstanceActionListener extends EventListener<UIInstance> {

    /**
     * The execute method of the listener
     * 
     * @throws Exception
     */
    public void execute(Event<UIInstance> event) throws Exception {
      UIInstance uii = event.getSource();
      UINovaViewManagement viewMgt = uii.getAncestorOfType(UINovaViewManagement.class);

      String instanceId = event.getRequestContext().getRequestParameter(UIComponent.OBJECTID);

      /*
       * === Non binded action yet === OrchestraService os =
       * uii.getApplicationComponent(OrchestraService.class);
       * os.deleteInstance(instanceId);
       */

      viewMgt.closeView(instanceId);
      viewMgt.showView("Instances");
    }
  }
}
